Paul Vriens : rsaenh: Add some new flags to wincrypt.h and use one of them.

Alexandre Julliard julliard at winehq.org
Thu Apr 3 05:43:51 CDT 2008


Module: wine
Branch: master
Commit: 51ee956b953501903ec13c9a2b052882d56429b2
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=51ee956b953501903ec13c9a2b052882d56429b2

Author: Paul Vriens <paul.vriens.wine at gmail.com>
Date:   Thu Apr  3 08:46:53 2008 +0200

rsaenh: Add some new flags to wincrypt.h and use one of them.

---

 dlls/rsaenh/rsaenh.c |    8 ++++----
 include/wincrypt.h   |   13 +++++--------
 2 files changed, 9 insertions(+), 12 deletions(-)

diff --git a/include/wincrypt.h b/include/wincrypt.h
index bf15b93..5d8b203 100644
--- a/include/wincrypt.h
+++ b/include/wincrypt.h
@@ -1816,14 +1816,6 @@ static const WCHAR MS_ENH_RSA_AES_PROV_W[] =           { 'M','i','c','r','o','s'
 
 /* FLAGS Section */
 
-/* Provider Parameters */
-#define PP_ENUMALGS             1
-#define PP_ENUMCONTAINERS       2
-#define PP_IMPTYPE              3
-#define PP_NAME                 4
-#define PP_VERSION              5
-#define PP_CONTAINER            6
-
 #define CRYPT_FIRST             1
 #define CRYPT_NEXT              2
 
@@ -1880,6 +1872,11 @@ static const WCHAR MS_ENH_RSA_AES_PROV_W[] =           { 'M','i','c','r','o','s'
 #define PP_USE_HARDWARE_RNG     38
 #define PP_KEYSPEC              39
 #define PP_ENUMEX_SIGNING_PROT  40
+#define PP_CRYPT_COUNT_KEY_USE  41
+#define PP_USER_CERTSTORE       42
+#define PP_SMARTCARD_READER     43
+#define PP_SMARTCARD_GUID       45
+#define PP_ROOT_CERTSTORE       46
 
 /* Values returned by CryptGetProvParam of PP_KEYSTORAGE */
 #define CRYPT_SEC_DESCR         0x00000001




More information about the wine-cvs mailing list
diff --git a/dlls/rsaenh/rsaenh.c b/dlls/rsaenh/rsaenh.c
index e31bace..14e67d7 100644
--- a/dlls/rsaenh/rsaenh.c
+++ b/dlls/rsaenh/rsaenh.c
@@ -3027,11 +3027,11 @@ BOOL WINAPI RSAENH_CPGetProvParam(HCRYPTPROV hProv, DWORD dwParam, BYTE *pbData,
     DWORD dwTemp;
     HKEY hKey;
    
     /* This is for dwParam 41, which does not seem to be documented
      * on MSDN. IE6 SP1 asks for it in the 'About' dialog, however.
      * Returning this BLOB seems to satisfy IE. The marked 0x00 seem 
      * to be 'don't care's. If you know anything more specific about
-     * provider parameter 41, please report to wine-devel at winehq.org */
+     * this provider parameter, please report to wine-devel at winehq.org */
     static CONST BYTE abWTF[96] = { 
         0xb0, 0x25,     0x63,     0x86, 0x9c, 0xab,     0xb6,     0x37, 
         0xe8, 0x82, /**/0x00,/**/ 0x72, 0x06, 0xb2, /**/0x00,/**/ 0x3b, 
@@ -3175,7 +3175,7 @@ BOOL WINAPI RSAENH_CPGetProvParam(HCRYPTPROV hProv, DWORD dwParam, BYTE *pbData,
                                   sizeof(PROV_ENUMALGS_EX));
             }
 
-        case 41: /* Undocumented. Asked for by IE About dialog */
+        case PP_CRYPT_COUNT_KEY_USE: /* Asked for by IE About dialog */
             return copy_param(pbData, pdwDataLen, abWTF, sizeof(abWTF));
 
         default:
@@ -3027,11 +3027,11 @@ BOOL WINAPI RSAENH_CPGetProvParam(HCRYPTPROV hProv, DWORD dwParam, BYTE *pbData,
     HKEY hKey;
    
-    /* This is for dwParam 41, which does not seem to be documented
-     * on MSDN. IE6 SP1 asks for it in the 'About' dialog, however.
+    /* This is for dwParam PP_CRYPT_COUNT_KEY_USE.
+     * IE6 SP1 asks for it in the 'About' dialog.
      * Returning this BLOB seems to satisfy IE. The marked 0x00 seem 
      * to be 'don't care's. If you know anything more specific about